@@ -15,6 +15,8 @@
 //!
 //! # Examples
 //!
+//! Retry with default settings.
+//!
 //! ```no_run
 //! use backon::Retryable;
 //! use backon::ExponentialBackoff;
@@ -27,8 +29,30 @@
 //! #[tokio::main]
 //! async fn main() -> Result<()> {
 //!     let content = fetch.retry(ExponentialBackoff::default()).await?;
-//!     println!("fetch succeeded: {}", content);
 //!
+//!     println!("fetch succeeded: {}", content);
+//!     Ok(())
+//! }
+//! ```
+//!
+//! Retry with specify retryable error.
+//!
+//! ```no_run
+//! use backon::Retryable;
+//! use backon::ExponentialBackoff;
+//! use anyhow::Result;
+//!
+//! async fn fetch() -> Result<String> {
+//!     Ok(reqwest::get("https://www.rust-lang.org").await?.text().await?)
+//! }
+//!
+//! #[tokio::main]
+//! async fn main() -> Result<()> {
+//!     let content = fetch
+//!         .retry(ExponentialBackoff::default())
+//!         .with_error_fn(|e| e.to_string() == "retryable").await?;
+//!
+//!     println!("fetch succeeded: {}", content);
 //!     Ok(())
 //! }
 //! ```
@@ -43,4 +67,5 @@ mod exponential;
 pub use exponential::ExponentialBackoff;
 
 mod retry;
+pub use retry::Retry;
 pub use retry::Retryable;
